@@ -13,7 +13,7 @@ from wordcloud import WordCloud, STOPWORDS
 from matplotlib import pyplot as plt
 from sklearn.preprocessing import minmax_scale
 from sklearn.compose import ColumnTransformer
-from keras.preprocessing.sequence import TimeseriesGenerator as SG
+from tensorflow.keras.preprocessing.sequence import TimeseriesGenerator as SG
 from sklearn.datasets import load_iris, load_boston
 from collections import Counter
 from .chart import Chart
